# aliro-honeywell
This is an api to connect to the Honeywell backend

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install
```sh
pip install aliro-honeywell
```

Then import the package:
```python
import aliro_honeywell
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import aliro_honeywell
from aliro_honeywell.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://qapi.honeywell.com/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = aliro_honeywell.Configuration(
    host = "https://qapi.honeywell.com/v1"
)



# Enter a context with an instance of the API client
with aliro_honeywell.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = aliro_honeywell.AuthenticationApi(api_client)
    login_post_parameters = aliro_honeywell.LoginPostParameters() # LoginPostParameters |  (optional)

    try:
        # This API returns an id-token and a refresh-token.
        api_response = api_instance.login_post(login_post_parameters=login_post_parameters)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AuthenticationApi->login_post: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://qapi.honeywell.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthenticationApi* | [**login_post**](docs/AuthenticationApi.md#login_post) | **POST** /login | This API returns an id-token and a refresh-token.
*JobApi* | [**job_job_id_cancel_post**](docs/JobApi.md#job_job_id_cancel_post) | **POST** /job/{job-id}/cancel | Previously submitted quantum job may be canceled using this API
*JobApi* | [**job_job_id_get**](docs/JobApi.md#job_job_id_get) | **GET** /job/{job-id} | Users monitor job status using job status API. In addition to this API, users may set notification preferences via user portal to allow email or text notifications related to job status. These portal-configured notifications are out of scope for this API specification.  Different results formatters may be added in the future via additional query string parameters. Current API specification supports raw results only.  To retrieve job status and results, the following API is used: 
*JobApi* | [**job_post**](docs/JobApi.md#job_post) | **POST** /job | Quantum job may be submitted using the following API
*MachineApi* | [**machine_get**](docs/MachineApi.md#machine_get) | **GET** /machine | This API returns a list of available machine names at that time.
*MachineApi* | [**machine_name_get**](docs/MachineApi.md#machine_name_get) | **GET** /machine/{name} | 
*MeteringApi* | [**metering_get**](docs/MeteringApi.md#metering_get) | **GET** /metering | Metering API is used to retrieve information about the jobs run and the number of QCU consumed within specific period of time. Metering requests can use date range, last X number of days or last Y number of jobs. 


## Documentation For Models

 - [ErrorResponse](docs/ErrorResponse.md)
 - [ErrorResponseError](docs/ErrorResponseError.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse2002](docs/InlineResponse2002.md)
 - [InlineResponse2003](docs/InlineResponse2003.md)
 - [InlineResponse2003Jobs](docs/InlineResponse2003Jobs.md)
 - [InlineResponseDefault](docs/InlineResponseDefault.md)
 - [InlineResponseDefault1](docs/InlineResponseDefault1.md)
 - [JobPostParameters](docs/JobPostParameters.md)
 - [JobResponse](docs/JobResponse.md)
 - [LoginPostParameters](docs/LoginPostParameters.md)


## Documentation For Authorization


## JwtKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

nick@aliroquantum.com


